@@ -315,6 +315,7 @@ env = _AttributeDict({
     'default_port': default_port,
     'eagerly_disconnect': False,
     'echo_stdin': True,
+    'effective_roles': [],
     'exclude_hosts': [],
     'gateway': None,
     'host': None,
@@ -340,6 +341,7 @@ env = _AttributeDict({
     'sudo_prompt': 'sudo password:',
     'sudo_user': None,
     'tasks': [],
+    'prompts': {},
     'use_exceptions_for': {'network': False},
     'use_shell': True,
     'use_ssh_config': False,
